@@ -3,7 +3,7 @@ from enum import Enum
 from telescope_sdk.common import UserFacingDataType
 
 
-class CampaignStatus(Enum):
+class CampaignStatus(str, Enum):
     RUNNING = 'RUNNING'
     PAUSED = 'PAUSED'
     ERROR = 'ERROR'
