@@ -24,6 +24,9 @@ class TelescopeBaseType(BaseModel):
     class Config:
         use_enum_values = True
 
+    def to_dynamodb_format(self) -> dict[str, any]:
+        return self.dict(exclude_none=True)
+
 
 class IngestedDataType(TelescopeBaseType):
     """
